@@ -1,10 +1,22 @@
 import os
+from enum import Enum
 from tempfile import NamedTemporaryFile
 
-import typer
-
 from click import BadParameter
-from sgpt import OpenAIClient
+
+
+class CompletionModes(Enum):
+    NORMAL = "normal"
+    SHELL = "shell"
+    CODE = "code"
+
+    @classmethod
+    def get_mode(cls, shell, code) -> "CompletionModes":
+        if shell:
+            return CompletionModes.SHELL
+        if code:
+            return CompletionModes.CODE
+        return CompletionModes.NORMAL
 
 
 def get_edited_prompt() -> str:
@@ -21,22 +33,9 @@ def get_edited_prompt() -> str:
     # This will write text to file using $EDITOR.
     os.system(f"{editor} {file_path}")
     # Read file when editor is closed.
-    with open(file_path, "r") as file:
+    with open(file_path, "r", encoding="utf-8") as file:
         output = file.read()
     os.remove(file_path)
     if not output:
         raise BadParameter("Couldn't get valid PROMPT from $EDITOR")
     return output
-
-
-def echo_chat_messages(chat_id: str) -> None:
-    # Prints all messages from a specified chat ID to the console.
-    for index, message in enumerate(OpenAIClient.chat_cache.show(chat_id)):
-        color = "cyan" if index % 2 == 0 else "green"
-        typer.secho(message, fg=color)
-
-
-def echo_chat_ids() -> None:
-    # Prints all existing chat IDs to the console.
-    for chat_id in OpenAIClient.chat_cache.list():
-        typer.echo(chat_id)
